@@ -10,3 +10,10 @@ try:
 except NameError:
     # Python3
     basestring_ = str
+
+try:
+    bytes('')
+    bytes_ = bytes
+except TypeError:
+    # Python3
+    bytes_  = lambda x: bytes(x, 'utf8')
