@@ -162,11 +162,19 @@ try:
     from sqlalchemy.sql import sqltypes
 except ImportError:
     from sqlalchemy import types as sqltypes
+# Handle the sqlalchemy ARRAY import change
+try:
+    from sqlalchemy.dialects.postgresql.array import ARRAY
+except ImportError:
+    from sqlalchemy.dialects.postgresql.base import ARRAY
+
 
 from sqlalchemy.schema import Table, Column, MetaData
+from sqlalchemy.dialects.mssql import base as mssql_dialect
 from sqlalchemy.dialects.oracle import base as oracle_dialect
 from sqlalchemy.dialects.postgresql.base import (
-    ARRAY, ischema_names, PGDialect, NUMERIC)
+    ischema_names, PGDialect, NUMERIC, SMALLINT, VARCHAR, TIMESTAMP, BYTEA,
+    BOOLEAN, TEXT)
 import re
 import operator
 
@@ -216,8 +224,30 @@ OPERATORS = {
     ('<>', False): not_(sqlops.in_op)
 }
 
+def basic_converter(new_type):
+    def converter(c):
+        old_args = c.type.__dict__
+        c.type = new_type()
+        c.type.__dict__.update(old_args)
+    return converter
+
+def length_stripper(new_type):
+    first = basic_converter(new_type)
+    def converter(c):
+        first(c)
+        c.type.__dict__['length'] = None
+    return converter
+
 CONVERSION_MAP = {
-    oracle_dialect.NUMBER: NUMERIC
+    oracle_dialect.NUMBER: basic_converter(NUMERIC),
+
+    mssql_dialect.TINYINT: basic_converter(SMALLINT),
+    mssql_dialect.NVARCHAR: basic_converter(VARCHAR),
+    mssql_dialect.DATETIME: basic_converter(TIMESTAMP),
+    mssql_dialect.VARBINARY: basic_converter(BYTEA),
+    mssql_dialect.IMAGE: basic_converter(BYTEA),
+    mssql_dialect.BIT: basic_converter(BOOLEAN),
+    mssql_dialect.TEXT: length_stripper(TEXT)
 }
 
 SORT_SUPPORT = {
@@ -476,6 +506,7 @@ class SqlAlchemyFdw(ForeignDataWrapper):
             only = None
         metadata.reflect(bind=engine,
                          schema=schema,
+                         views=True,
                          only=only)
         to_import = []
         for _, table in sorted(metadata.tables.items()):
@@ -488,10 +519,8 @@ class SqlAlchemyFdw(ForeignDataWrapper):
                 # If the type is specialized, call the generic
                 # superclass method
                 if type(c.type) in CONVERSION_MAP:
-                    class_name = CONVERSION_MAP[type(c.type)]
-                    old_args = c.type.__dict__
-                    c.type = class_name()
-                    c.type.__dict__.update(old_args)
+                    converter = CONVERSION_MAP[type(c.type)]
+                    converter(c)
                 if c.primary_key:
                     ftable.options['primary_key'] = c.name
                 ftable.columns.append(ColumnDefinition(
