@@ -1,5 +1,9 @@
 #include "multicorn.h"
+#if PG_VERSION_NUM < 120000
 #include "optimizer/var.h"
+#else
+#include "optimizer/optimizer.h"
+#endif
 #include "optimizer/clauses.h"
 #include "optimizer/pathnode.h"
 #include "optimizer/subselect.h"
@@ -10,6 +14,12 @@
 #include "utils/lsyscache.h"
 #include "miscadmin.h"
 #include "parser/parsetree.h"
+#include "pg_config.h"
+
+/* Third argument to get_attname was introduced in [8237f27] (release 11) */
+#if PG_VERSION_NUM >= 110000
+#define get_attname(x, y) get_attname(x, y, true)
+#endif
 
 void extractClauseFromOpExpr(Relids base_relids,
 						OpExpr *node,
@@ -103,7 +113,7 @@ initConversioninfo(ConversionInfo ** cinfos, AttInMetadata *attinmeta)
 
 	for (i = 0; i < attinmeta->tupdesc->natts; i++)
 	{
-		Form_pg_attribute attr = attinmeta->tupdesc->attrs[i];
+		Form_pg_attribute attr = TupleDescAttr(attinmeta->tupdesc,i);
 		Oid			outfuncoid;
 		bool		typIsVarlena;
 
