@@ -1,9 +1,10 @@
 SET client_min_messages=NOTICE;
+\i test-common/disable_jit.include
 CREATE EXTENSION multicorn;
 CREATE server multicorn_srv foreign data wrapper multicorn options (
     wrapper 'multicorn.testfdw.TestForeignDataWrapper'
 );
-CREATE user mapping for postgres server multicorn_srv options (usermapping 'test');
+CREATE user mapping FOR current_user server multicorn_srv options (usermapping 'test');
 
 -- Test for two thing: first, that when a low total row count, 
 -- a full seq scan is used on a join.
@@ -38,5 +39,5 @@ explain select * from testmulticorn m1 inner join testmulticorn m2 on m1.test1 =
 
 explain select * from testmulticorn m1 left outer join testmulticorn m2 on m1.test1 = m2.test1;
 
-DROP USER MAPPING for postgres SERVER multicorn_srv;
+DROP USER MAPPING FOR current_user SERVER multicorn_srv;
 DROP EXTENSION multicorn cascade;
