@@ -4,7 +4,7 @@ CREATE EXTENSION hstore;
 CREATE server multicorn_srv foreign data wrapper multicorn options (
     wrapper 'multicorn.testfdw.TestForeignDataWrapper'
 );
-CREATE user mapping for postgres server multicorn_srv options (usermapping 'test');
+CREATE user mapping FOR current_user server multicorn_srv options (usermapping 'test');
 
 CREATE foreign table testmulticorn (
     test1 hstore,
@@ -18,5 +18,5 @@ CREATE foreign table testmulticorn (
 select * from testmulticorn;
 
 select test1 -> 'repeater' as r from testmulticorn order by r;
-DROP USER MAPPING FOR postgres SERVER multicorn_srv;
+DROP USER MAPPING FOR current_user SERVER multicorn_srv;
 DROP EXTENSION multicorn cascade;
