@@ -2,7 +2,7 @@ CREATE EXTENSION multicorn;
 CREATE server multicorn_srv foreign data wrapper multicorn options (
     wrapper 'multicorn.testfdw.TestForeignDataWrapper'
 );
-CREATE user mapping for postgres server multicorn_srv options (usermapping 'test');
+CREATE user mapping FOR current_user server multicorn_srv options (usermapping 'test');
 
 CREATE foreign table testmulticorn (
     test1 character varying,
@@ -139,5 +139,5 @@ DROP foreign table testmulticorn_write;
 ROLLBACK;
 
 -- Clean up
-DROP USER MAPPING FOR postgres SERVER multicorn_srv;
+DROP USER MAPPING FOR current_user SERVER multicorn_srv;
 DROP EXTENSION multicorn cascade;
